SparseAccessorIndices class
An object pointing to a buffer view containing the indices of deviating
accessor values.
The number of indices is equal to accessor.sparse.count. Indices MUST
strictly increase.
Constructors
-
SparseAccessorIndices({required GltfRoot root, required GltfRef<
BufferView> bufferView, required int byteOffset, required ComponentType componentType}) -
SparseAccessorIndices.parse(GltfRoot root, Map<
String, Object?> map)
Properties
-
bufferView
→ GltfRef<
BufferView> -
The reference to the buffer view with sparse indices.
The referenced buffer view MUST NOT have its
targetorbyteStrideproperties defined. The buffer view and the optionalbyteOffsetMUST be aligned to thecomponentTypebyte length."final - byteOffset → int
-
The offset relative to the start of the buffer view in bytes.
final
- componentType → ComponentType
-
The indices data type.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- root → GltfRoot
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited